# Unknown error
api_test_error_message = "API tester error"
wrong_http_method_error_message = "wrong http method"
http_method_have_wrong_type = "get wrong type param"
# get data error
api_test_get_data_error_message = "API tester can't get api data error"
# API Http Method error
api_test_get_error_message = "API tester get error"
api_test_get_json_error_message = "API tester get json error"
api_test_put_error_message = "API tester put error"
api_test_delete_error_message = "API tester delete error"
api_test_post_error_message = "API tester post error"
api_test_head_error_message = "API tester head error"
api_test_options_error_message = "API tester options error"
api_test_patch_error_message = "API tester patch error"
api_test_session_error_message = "API tester session error"
# API response code error
api_test_response_code_error = "API tester get wrong response code"
# API response body error
api_test_response_body_error = "API tester get wrong response body"
# API response timeout error
api_test_response_timeout_error = "API tester timeout"
# API response history error
api_test_response_history_error = "API tester history error"
# API response encoding error
api_test_response_encoding_error = "API tester encoding error"
# API response cookies error
api_test_response_cookies_error = "API tester cookies error"
# API response headers error
api_test_response_headers_error = "API tester headers error"
# API response content error
api_test_response_content_error = "API tester content error"
# API response text error
api_test_response_text_error = "API tester text error"
# API execute action error
api_test_execute_action_error = "can't execute action"
# API json error
api_test_cant_find_json_error = "can't find json"
api_test_cant_save_json_error = "can't save json"
api_test_cant_reformat_json_error = "can't reformat json is type right?"
api_test_cant_find_element_in_json_error = "can't find element in json"
api_test_json_type_error = "json type error"
wrong_json_data_error = "can't parser json"
# API XML error
api_test_cant_read_xml_error = "can't read xml"
api_test_xml_type_error = "xml type error"
# Executor error
executor_data_error = "executor receive wrong data"
executor_list_error = "executor receive wrong data list is none or wrong type"
# API data check
status_code_error = "request status code error"
status_text_error = "request text error"
status_content_error = "request content error"
status_headers_error = "request headers error"
status_history_error = "request history error"
status_encoding_error = "request encoding error"
status_cookies_error = "request cookies error"
status_elapsed_error = "request elapsed error"
status_requests_method_error = "requests method error"
status_requests_url_error = "requests url error"
status_requests_body_error = "requests body error"
# HTML
html_generate_no_data_tag = "record is None"

